Struct farcaster_core::crypto::slip10::DerivationPath
source · pub struct DerivationPath(_);Available on crate feature
experimental only.Expand description
A BIP-32 derivation path.
Implementations
sourceimpl DerivationPath
impl DerivationPath
sourcepub fn master() -> DerivationPath
pub fn master() -> DerivationPath
Returns derivation path for a master key (i.e. empty derivation path)
sourcepub fn is_master(&self) -> bool
pub fn is_master(&self) -> bool
Returns whether derivation path represents master key (i.e. it’s length
is empty). True for m path.
sourcepub fn child(&self, cn: ChildNumber) -> DerivationPath
pub fn child(&self, cn: ChildNumber) -> DerivationPath
Create a new DerivationPath that is a child of this one.
sourcepub fn into_child(self, cn: ChildNumber) -> DerivationPath
pub fn into_child(self, cn: ChildNumber) -> DerivationPath
Convert into a DerivationPath that is a child of this one.
sourcepub fn children_from(&self, cn: ChildNumber) -> DerivationPathIterator<'_>
pub fn children_from(&self, cn: ChildNumber) -> DerivationPathIterator<'_>
Get an Iterator over the children of this DerivationPath starting with the given ChildNumber.
sourcepub fn normal_children(&self) -> DerivationPathIterator<'_>
pub fn normal_children(&self) -> DerivationPathIterator<'_>
Get an Iterator over the unhardened children of this DerivationPath.
sourcepub fn hardened_children(&self) -> DerivationPathIterator<'_>
pub fn hardened_children(&self) -> DerivationPathIterator<'_>
Get an Iterator over the hardened children of this DerivationPath.
sourcepub fn extend<T>(&self, path: T) -> DerivationPathwhere
T: AsRef<[ChildNumber]>,
pub fn extend<T>(&self, path: T) -> DerivationPathwhere
T: AsRef<[ChildNumber]>,
Concatenate self with path and return the resulting new path.
use bitcoin::util::bip32::{DerivationPath, ChildNumber};
use std::str::FromStr;
let base = DerivationPath::from_str("m/42").unwrap();
let deriv_1 = base.extend(DerivationPath::from_str("m/0/1").unwrap());
let deriv_2 = base.extend(&[
ChildNumber::from_normal_idx(0).unwrap(),
ChildNumber::from_normal_idx(1).unwrap()
]);
assert_eq!(deriv_1, deriv_2);Trait Implementations
sourceimpl AsRef<[ChildNumber]> for DerivationPath
impl AsRef<[ChildNumber]> for DerivationPath
sourcefn as_ref(&self) -> &[ChildNumber]
fn as_ref(&self) -> &[ChildNumber]
Converts this type into a shared reference of the (usually inferred) input type.
sourceimpl Clone for DerivationPath
impl Clone for DerivationPath
sourcefn clone(&self) -> DerivationPath
fn clone(&self) -> DerivationPath
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DerivationPath
impl Debug for DerivationPath
sourceimpl Default for DerivationPath
impl Default for DerivationPath
sourcefn default() -> DerivationPath
fn default() -> DerivationPath
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for DerivationPath
impl<'de> Deserialize<'de> for DerivationPath
sourcefn deserialize<D>(
deserializer: D
) -> Result<DerivationPath, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D
) -> Result<DerivationPath, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for DerivationPath
impl Display for DerivationPath
sourceimpl<'a> From<&'a [ChildNumber]> for DerivationPath
impl<'a> From<&'a [ChildNumber]> for DerivationPath
sourcefn from(numbers: &'a [ChildNumber]) -> DerivationPath
fn from(numbers: &'a [ChildNumber]) -> DerivationPath
Converts to this type from the input type.
sourceimpl From<Vec<ChildNumber, Global>> for DerivationPath
impl From<Vec<ChildNumber, Global>> for DerivationPath
sourcefn from(numbers: Vec<ChildNumber, Global>) -> DerivationPath
fn from(numbers: Vec<ChildNumber, Global>) -> DerivationPath
Converts to this type from the input type.
sourceimpl FromIterator<ChildNumber> for DerivationPath
impl FromIterator<ChildNumber> for DerivationPath
sourcefn from_iter<T>(iter: T) -> DerivationPathwhere
T: IntoIterator<Item = ChildNumber>,
fn from_iter<T>(iter: T) -> DerivationPathwhere
T: IntoIterator<Item = ChildNumber>,
Creates a value from an iterator. Read more
sourceimpl FromStr for DerivationPath
impl FromStr for DerivationPath
sourceimpl Hash for DerivationPath
impl Hash for DerivationPath
sourceimpl<I> Index<I> for DerivationPathwhere
Vec<ChildNumber, Global>: Index<I>,
impl<I> Index<I> for DerivationPathwhere
Vec<ChildNumber, Global>: Index<I>,
sourceimpl Into<Vec<ChildNumber, Global>> for DerivationPath
impl Into<Vec<ChildNumber, Global>> for DerivationPath
sourceimpl<'a> IntoIterator for &'a DerivationPath
impl<'a> IntoIterator for &'a DerivationPath
type Item = &'a ChildNumber
type Item = &'a ChildNumber
The type of the elements being iterated over.
type IntoIter = Iter<'a, ChildNumber>
type IntoIter = Iter<'a, ChildNumber>
Which kind of iterator are we turning this into?
sourcefn into_iter(self) -> <&'a DerivationPath as IntoIterator>::IntoIter
fn into_iter(self) -> <&'a DerivationPath as IntoIterator>::IntoIter
Creates an iterator from a value. Read more
sourceimpl Ord for DerivationPath
impl Ord for DerivationPath
sourcefn cmp(&self, other: &DerivationPath) -> Ordering
fn cmp(&self, other: &DerivationPath) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<DerivationPath> for DerivationPath
impl PartialEq<DerivationPath> for DerivationPath
sourcefn eq(&self, other: &DerivationPath) -> bool
fn eq(&self, other: &DerivationPath) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<DerivationPath> for DerivationPath
impl PartialOrd<DerivationPath> for DerivationPath
sourcefn partial_cmp(&self, other: &DerivationPath) -> Option<Ordering>
fn partial_cmp(&self, other: &DerivationPath) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl<'de> Serialize for DerivationPath
impl<'de> Serialize for DerivationPath
sourcefn serialize<S>(
&self,
serializer: S
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
sourceimpl StrictDecode for DerivationPath
impl StrictDecode for DerivationPath
sourcefn strict_decode<D>(d: D) -> Result<DerivationPath, Error>where
D: Read,
fn strict_decode<D>(d: D) -> Result<DerivationPath, Error>where
D: Read,
Decode with the given
std::io::Read instance; must either
construct an instance or return implementation-specific error type.sourcefn strict_deserialize(data: impl AsRef<[u8]>) -> Result<Self, Error>
fn strict_deserialize(data: impl AsRef<[u8]>) -> Result<Self, Error>
Tries to deserialize byte array into the current type using
StrictDecode::strict_decode. If there are some data remains in the
buffer once deserialization is completed, fails with
Error::DataNotEntirelyConsumed. Use io::Cursor over the buffer and
StrictDecode::strict_decode to avoid such failures.sourcefn strict_file_load(path: impl AsRef<Path>) -> Result<Self, Error>
fn strict_file_load(path: impl AsRef<Path>) -> Result<Self, Error>
Reads data from file at
path and reconstructs object from it. Fails
with Error::DataNotEntirelyConsumed if file contains remaining
data after the object reconstruction.sourceimpl StrictEncode for DerivationPath
impl StrictEncode for DerivationPath
sourcefn strict_encode<E>(&self, e: E) -> Result<usize, Error>where
E: Write,
fn strict_encode<E>(&self, e: E) -> Result<usize, Error>where
E: Write,
Encode with the given
std::io::Write instance; must return result
with either amount of bytes encoded – or implementation-specific
error type.sourcefn strict_serialize(&self) -> Result<Vec<u8, Global>, Error>
fn strict_serialize(&self) -> Result<Vec<u8, Global>, Error>
Serializes data as a byte array using
StrictEncode::strict_encode
functionimpl Eq for DerivationPath
impl StructuralEq for DerivationPath
impl StructuralPartialEq for DerivationPath