pub trait RecoverSecret<PublicKey, SecretKey, Signature, EncryptedSignature> {
    fn recover_secret_key(
        &self,
        encrypted_sig: EncryptedSignature,
        encryption_key: &PublicKey,
        sig: Signature
    ) -> SecretKey; }
Recover the secret key through the complete encrypted/decrypted signature and public encryption key.

Required Methods

Recover the encryption key based on the encrypted signature, the encryption public key, and the regular (decrypted) signature.

Implementors