Module farcaster_core::role
source · Expand description
Roles used to distinguish participants and blockchains during trade setup and swap phase. Defines the trading roles and swap roles distributed among participants and blockchain roles implemented on Bitcoin, Monero, etc.
Enums
Possible roles during the trade setup. Trade roles are orthogonal to swap roles:
any trade role can transition into any swap role, but the the particular transition
that will happen is agreed upon & set in the deal.
Traits
An accordant is the blockchain which does not need transaction inside the protocol nor
timelocks: it is the blockchain with fewer requirements for an atomic swap.